@@ -1,14 +1,14 @@
 import json
 
 from django import forms
-from django.conf.urls import url
 from django.contrib import admin
 from django.contrib.contenttypes.admin import GenericStackedInline
 from django.core.exceptions import ValidationError
 from django.http import JsonResponse
 from django.shortcuts import get_object_or_404
+from django.urls import path
 from django.utils.functional import cached_property
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from leaflet.admin import LeafletGeoAdmin
 
 from openwisp_utils.admin import TimeReadonlyAdminMixin
@@ -45,6 +45,7 @@ class AbstractLocationForm(forms.ModelForm):
             'admin/js/jquery.init.js',
             'django-loci/js/loci.js',
             'django-loci/js/floorplan-inlines.js',
+            'django-loci/js/vendor/reconnecting-websocket.min.js',
         )
         css = {'all': ('django-loci/css/loci.css',)}
 
@@ -69,23 +70,23 @@ class AbstractLocationAdmin(TimeReadonlyAdminMixin, LeafletGeoAdmin):
         # without having to change templates
         app_label = 'django_loci'
         return [
-            url(
-                r'^(?P<pk>[^/]+)/json/$',
+            path(
+                '<uuid:pk>/json/',
                 self.admin_site.admin_view(self.json_view),
                 name='{0}_location_json'.format(app_label),
             ),
-            url(
-                r'^(?P<pk>[^/]+)/floorplans/json/$',
+            path(
+                '<uuid:pk>/floorplans/json/',
                 self.admin_site.admin_view(self.floorplans_json_view),
                 name='{0}_location_floorplans_json'.format(app_label),
             ),
-            url(
-                r'^geocode/$',
+            path(
+                'geocode/',
                 self.admin_site.admin_view(geocode_view),
                 name='{0}_location_geocode_api'.format(app_label),
             ),
-            url(
-                r'^reverse-geocode/$',
+            path(
+                'reverse-geocode/',
                 self.admin_site.admin_view(reverse_geocode_view),
                 name='{0}_location_reverse_geocode_api'.format(app_label),
             ),
@@ -187,6 +188,7 @@ class AbstractObjectLocationForm(forms.ModelForm):
             'admin/js/jquery.init.js',
             'django-loci/js/loci.js',
             'django-loci/js/floorplan-widget.js',
+            'django-loci/js/vendor/reconnecting-websocket.min.js',
         )
         css = {
             'all': ('django-loci/css/loci.css', 'django-loci/css/floorplan-widget.css')
