@@ -54,11 +54,11 @@ django.jQuery(function ($) {
     if (!gettext) { window.gettext = function (text) { return text; }; }
 
     function getLocationJsonUrl(pk) {
-        return baseLocationJsonUrl.replace('0000', pk);
+        return baseLocationJsonUrl.replace('00000000-0000-0000-0000-000000000000', pk);
     }
 
     function getLocationFloorplansJsonUrl(pk) {
-        return baseLocationFloorplansJsonUrl.replace('0000', pk);
+        return baseLocationFloorplansJsonUrl.replace('00000000-0000-0000-0000-000000000000', pk);
     }
 
     function getMap() {
@@ -370,7 +370,7 @@ django.jQuery(function ($) {
     function listenForLocationUpdates(pk) {
         var host = window.location.host,
             protocol = window.location.protocol === 'http:' ? 'ws' : 'wss',
-            ws = new WebSocket(protocol + '://' + host + '/ws/loci/location/' + pk + '/');
+            ws = new ReconnectingWebSocket(protocol + '://' + host + '/ws/loci/location/' + pk + '/');
         ws.onmessage = function (e) {
             $geometryRow.show();
             $noLocationDiv.hide();
